pyparsing.pyparsing.OnlyOnce

Package pyparsing :: Module pyparsing :: Class OnlyOnce |
[frames | no frames]

## Type OnlyOnce

    object --+
             |
            OnlyOnce

Wrapper for parse actions, to ensure they are only called once.

Method Summary
| `__init__(self, methodCall)`
| `__call__(self, s, l, t)`
| `reset(self)`
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Generated by Epydoc 2.1 on Sun Feb 10 18:01:06 2008 | http://epydoc.sf.net